@@ -91,7 +91,10 @@ class FileServerConnector:
         args = {"filename": filename, "is_thumbnail_required": is_thumbnail_required}
         answer = await self._connector.post("/file/add", payload=file, url_query=args,
                                             headers=self._construct_headers())
-        return dict_to_dataclass(answer, FileLink)
+        original = answer.get("original")
+        if not original:
+            raise ValueError('Wrong answer structure: {original}')
+        return dict_to_dataclass(original, FileLink)
 
     async def delete_file(self, file_id: str) -> FileLink:
         args = {"id": file_id}
